花样年华 (豆瓣)
Description: 花样年华电影简介和剧情介绍,花样年华影评、图片、预告片、影讯、论坛、在线购票
Keywords: 花样年华,花樣年華,花样年华影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.156豆瓣电影Top250

# 花样年华 花樣年華 (2000)

导演: 王家卫
编剧: 王家卫
主演: 梁朝伟 / 张曼玉 / 潘迪华 / 萧炳林 / 张耀扬 / 孙佳君 / 钱似莺 / 顾锦华
类型: 剧情 / 爱情
制片国家/地区: 中国香港
语言: 粤语 / 上海话 / 法语
上映日期: 2000-09-29(中国香港) / 2000-05-20(戛纳电影节)
片长: 98 分钟
又名: In the Mood for Love
IMDb: tt0118694
豆瓣评分
引用
8.7
568873人评价
5星
48.3%
4星
41.1%
3星
9.7%
2星
0.6%
1星
0.2%
好于 98% 爱情片
好于 97% 剧情片
想看 看过
评价:
推荐

## 花样年华的剧情简介 · · · · · ·

1960年代的香港，报馆编辑周慕云（梁朝伟 饰）与太太搬进一间住户多是上海人的公寓，和某家日资公司的贸易代表陈先生与太太苏丽珍（张曼玉 饰）成了邻居。因为发现各自在外工作的配偶背着他们有了婚外情，周慕云和苏丽珍开始见面商讨未来可能发生的事情以及相应对策。
起初两人是君子之交淡如水就事谈事，可是日子一日接一日过去后，在周围一帮上海邻居的闲言碎语中，他们发现配偶的事早空出了他们的脑袋，彼此眼里只剩下了对方，而刻意回避已生出的感情的结果，是更加刻骨的相思。 ©豆瓣

## 花样年华的演职员 · · · · · · ( 全部 27 )

- 王家卫 导演
- 梁朝伟 饰 周慕云
- 张曼玉 饰 苏丽珍
- 潘迪华 饰 孙太太
- 萧炳林 饰 阿炳
- 张耀扬 饰 陈先生

## 花样年华的视频和图片 · · · · · · ( 预告片3 | 视频评论2 · 添加 | 图片2278 · 添加 )

## 花样年华的获奖情况 · · · · · · ( 全部 )

- 第53届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 王家卫

- 第37届台北金马影展
- 金马奖 最佳剧情片(提名)

- 第20届香港电影金像奖
- 最佳电影(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  重庆森林

  甜蜜蜜

  2046

  阿飞正传

  罗马假日

  爱在黎明破晓前

  堕落天使

  胭脂扣

  春光乍泄

  天使爱美丽

我要写短评

## 花样年华的短评 · · · · · · ( 全部 125970 条 )

热门 / 最新 / 好友

### 8417 有用 Ruby超人小姐 看过 2010-04-20 07:57:12

张曼玉比梁朝伟高，但他们站在一起那么协调。想来，是穿了高跟鞋的她，懂得委婉地低头的缘故。

### 2252 有用 青灯有味 看过 2007-11-16 10:36:18

君知妾有夫，赠妾双明珠。 感君缠绵意，系在红罗襦。 妾家高楼连苑起，良人执戟明光里。 感君用心同日月，誓拟侍君同生死。 还君明珠双泪垂，恨不相逢未嫁时。

### 3849 有用 醉舟 看过 2012-09-10 00:04:35

They are in the mood for love, but not in the time and place for it. 剧本很有意思，设置了一对在电影里没有任何镜头的偷情男女，却又无时不刻地提醒着周慕云和苏丽珍不要做爱，所以王家卫镜头里沉闷的男女，空荡的房间里充斥着一种不可得的情欲，极省略的叙事，舒缓优雅的大提琴曲配乐实在是太到

### 5655 有用 寂地 看过 2006-01-02 15:32:54

王家卫最强的,就是让人掉到一种情绪中去

### 2834 有用 颜叙 看过 2012-01-02 20:54:21

深夜，雨巷，慢镜头；暧昧，寡欢，语还休。与君淡如水，千杯亦不醉。

> 更多短评 125970条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 花样年华的影评 · · · · · · ( 全部 2063 条 )

热门 / 最新 / 好友
蓝房子的守候 2008-11-29 23:17:47

## 最美好的年华与最糟糕的爱情。

同许多人一样，最初对这部电影产生兴趣，是想欣赏张曼玉在影片里穿着各款旗袍袅袅婷婷走过去的身姿。然而影片看到一半，便不得不重新定位王家卫频频拍摄的这一组镜头的作用，它是一道鲜明有力的色彩，却也只是色彩，它的存在与电影中压抑的大提琴音乐一样，都是为突显这样... (展开)
9282 282 430回应 收起
ydp123 2007-06-06 10:10:03

## 花样年华 的艺术魅力

《花样年华》被称为一部怀旧经典。就影片所讲述的故事本身而言，古老而又普通，没有什么新意，无非就是一个讲述婚外恋的爱情故事；就影片的情节来说，既不曲折也不扣人心弦，可以说简单而又平淡。那么，为什么这样一部故事普通、情节简单的影片能被人们称之为经典？关键就在于... (展开)
5495 173 292回应 收起
苏烟 2006-06-18 20:20:27

## 消逝地年华

如果多一张船票，你会不会和我一起走？” 摇曳的旗袍，昏黄的路灯，梳的一丝不苟的爱司头，一切欲说还羞的情感，如一张泛黄的老唱盘，在岁月的留声机中静静旋转。没有喧闹的浮躁，没有泡沫文化的缩影，只是哀婉却唯美地唱着一首老歌：花样年华。一部不俗的电影... (展开)
1786 93 179回应 收起
蛋白斯基 2009-12-25 19:07:52

## 残念 以及浮生若梦

我在东京，很想打电话给你。这里有很多的av可以买，可以坐新干线去悦子的大阪。 我在熊本，口吞着豚骨拉面。想起你说这难吃的像3块钱一碗的青菜面。 我想起了跟你在一起的许多事。在一座小城里，你幻梦所以我幻梦。穿过熙熙攘攘的涩谷街头，我曾经告诉过你，这里在日文中叫做sh... (展开)
546 45 62回应 收起
叶落姗姗 2008-12-10 10:52:27

## 爱情形而上

「1」 　　第一次看《花样年华》，不记得是在什么时候。若非为了写点什么，大抵永远不会再看第二遍。不是这个电影不好。只是它本身其实就像是一团雾气，再看也是模糊。而我以为，它的精华也尽在这模糊里，隐隐约约、欲说还休、欲罢不能……直到最后也没落个清明，就不了了... (展开)
335 38 36回应 收起
凌麦儿 2009-10-22 01:42:04

## 岁月荏苒中的光影袅袅——《花样年华》视听语言分析

（hmmm这是很多年前的视听语言课作业，回头看时自己都觉得有点尴尬，就……各方面都挺有年代感的，被大家收藏真是诚惶诚恐，感谢各位厚爱……不过本人当年是新闻专业学生，视听语言课只是一个选修，所以不是编导相关啦~） 《花样年华》的开头为观众描绘了这样的场景：简单的字... (展开)
448 8 25回应 收起
Shan 2016-06-02 19:28:09

## “那是一种难堪的相对”——评王家卫《花样年华》

这篇影评可能有剧透

六十年代的香港，晦暗老旧的房屋，两对青年夫妻，故事便这样展开……周太太和陈先生偷情被陈太太苏丽珍和周先生周慕云发现，自然而然，他们成为一对“苦命”的人，他们互诉衷肠，模拟出轨者怎样开始的情景。他们有意无意地约会，共进晚餐、一起编写武侠小说、一起讨论... (展开)
578 111 98回应 收起
Sarah 2005-11-28 20:41:42

## 华丽的忧伤

看过这部影片的人,都会为梁和张的演技叫绝.加上杜可风的摄影绝技,在噶纳电影节上获得几个大奖也是很应该的. 其中那句经典已经家喻户晓:"如果我有多一张船票,你会不会跟我走."在这场华丽的邂逅中,一切都象梁手里的香烟一样 ,永远是漂在上空的。不管表明不表明,不管在意不... (展开)
172 13 37回应 收起
狐狸先生的货车 2015-12-28 10:52:03

## 两个黄鹂鸣翠柳，一枝红杏出墙来

楼梯弄堂人隐隐，几多喧闹几许深，参商相隔亦转瞬。 记2046相铭心，昔年风物似如今，只无与人共登临。 回廊一寸相思地，石板路上满氤氲，欲罢难休君莫恨。 苏家芳梅暗香隐，落月孤倚就花阴，十年踪迹十年心。 我是人间惆怅客，知君何事寻树洞，断肠声里忆平生。 相思相忆知... (展开)
125 10 6回应 收起

> 更多影评 2063篇

添加新讨论

## 讨论区 · · · · · ·

一场无需做爱就能达到的高潮 | 来自乔元元 |  | 2022-11-24 03:14:58
王家卫比李安差太多 | 来自20120328 | 103 回应 | 2022-11-24 02:52:55
为什么陈太那么美，陈生还搞周太？ | 来自茉 | 17 回应 | 2022-11-24 00:48:49
大家会为了真爱抛下所谓道德和贞洁吗 | 来自Pegasus | 9 回应 | 2022-11-19 21:47:53
微妙的感情 | 来自梦妮儿爱唠叨 |  | 2022-11-15 19:53:46

> 去这部影片的讨论区（全部352条）

## 关于《花样年华》的问题 · · · · · · ( 全部31个 )

- 为什么苏丽珍是上海人不说上海话？ 10人回答
- 很想问，那么多款旗袍，艳丽的，素雅的，是不是也在隐喻故事主人公的情感变化？ 6人回答

> 全部31个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 文艺女王必修课「华语篇」 (不良生)
- 179部经典港片 (德拉库拉拉)
- 100部爱情电影 经典的回味 (isay)

## 谁在看这部电影 · · · · · ·

- -阿怪
  1分钟前 想看
- 再见白丝
  1分钟前 想看
- 奔赴生活
  3分钟前 看过

852276人看过 / 237090人想看

订阅花样年华的评论:
feed: rss 2.0